Clojure only.

conquerant.core


asynccljmacro

(async expr)

If expr is a fn or defn form, its body will run asyncronously. Otherwise, expr will itself run asyncronously, and return a CompletableFuture.

All async exectution occurs on the ci/*executor* pool, which is bound to the common ForkJoinPool by default.

If `expr` is a `fn` or `defn` form, its body will
run asyncronously. Otherwise, `expr` will itself
run asyncronously, and return a `CompletableFuture`.

All async exectution occurs on the `ci/*executor*` pool,
which is bound to the common ForkJoinPool by default.
raw docstring

awaitclj

(await v)

Use inside async let blocks:

(async (let [x (async :x) y (await x)] y))

Will wait for the Completablefuture to complete before evaluation resumes.

Use inside `async` `let` blocks:

(async
  (let [x (async :x)
        y (await x)]
    y))

Will wait for the `Completablefuture` to complete
before evaluation resumes.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries